﻿using Infragistics.Windows.DataPresenter;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Runtime.CompilerServices;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace XamDataGrid_sample
{
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();      
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            xamDataGrid1.FieldLayoutSettings.AutoGenerateFields = false;

            FieldLayout fieldLayout1 = new FieldLayout();
            fieldLayout1.Key = "FieldLayout1";
            xamDataGrid1.FieldLayouts.Add(fieldLayout1);

            // ★Id 列を編集不可とするため、Id列のFiledオブジェクトを生成
            var idField = new Field("Id");
            idField.Name = "Id";
            idField.Label = "ID";

            // ★Id 列の IsAllowEdit（初期値が false）をBinding する
            var binding = new Binding
            {
                Path = new PropertyPath("DataContext.IsAllowEdit"),
                RelativeSource = RelativeSource.Self
            };

            // ★ Field.AllowEditProperty にバインド
            BindingOperations.SetBinding(idField, Field.AllowEditProperty, binding);

            // ★idField を追加
            fieldLayout1.Fields.Add(idField);

            var nameField = new Field("Name");
            nameField.Name = "Name";
            nameField.Label = "NAME";

            fieldLayout1.Fields.Add(nameField);


            // ★DataSource Binding
            var dataSourceBinding = new Binding
            {
                Path = new PropertyPath("Items")
            };
            BindingOperations.SetBinding(xamDataGrid1, XamDataGrid.DataSourceProperty, dataSourceBinding);
        }

    }


    public class Item : NotificationObject
    {
        private int _id;
        public int Id
        { 
            get { return _id; }
            set { _id = value; OnPropertyChanged(); }
        }

        private string _name;
        public string Name
        {
            get { return _name; }
            set { _name = value; OnPropertyChanged(); }
        }
    }

    public class NotificationObject : INotifyPropertyChanged
    {
        public event PropertyChangedEventHandler PropertyChanged;

        protected void OnPropertyChanged([CallerMemberName] String propertyName = null)
        {
            this.PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));

        }
    }
}
